@@ -35,9 +35,9 @@
 #include <sys/types.h>
 #include <sys/wait.h>
 #include <fcntl.h>
-#ifdef __sun
+#ifndef _WIN32
 #include <signal.h>
-#endif /* __sun */
+#endif /* _WIN32 */
 
 #ifndef WINDOWS
 #include <sys/socket.h>
@@ -95,6 +95,8 @@ kill_curl (pid_t pid)
 static ssize_t
 push_callback (void *cls, uint64_t pos, char *buf, size_t max)
 {
+  (void)cls;(void)pos;	/* Unused. Silent compiler warning. */
+
   if (max == 0)
     return 0;
   buf[0] = 'd';
@@ -125,6 +127,8 @@ ahc_echo (void *cls,
   const char *me = cls;
   struct MHD_Response *response;
   int ret;
+  (void)url;(void)version;                      /* Unused. Silent compiler warning. */
+  (void)upload_data;(void)upload_data_size;     /* Unused. Silent compiler warning. */
 
   //fprintf (stderr, "In CB: %s!\n", method);
   if (0 != strcmp (me, method))
@@ -153,17 +157,40 @@ testInternalGet ()
 {
   struct MHD_Daemon *d;
   pid_t curl;
+  int port;
+  char url[127];
+
+  if (MHD_NO != MHD_is_feature_supported (MHD_FEATURE_AUTODETECT_BIND_PORT))
+    port = 0;
+  else
+    {
+      port = 1180;
+      if (oneone)
+        port += 10;
+    }
 
   ok = 1;
   d = MHD_start_daemon (MHD_USE_INTERNAL_POLLING_THREAD | MHD_USE_ERROR_LOG,
-                        11080, NULL, NULL, &ahc_echo, "GET", MHD_OPTION_END);
+                        port, NULL, NULL, &ahc_echo, "GET", MHD_OPTION_END);
   if (d == NULL)
     return 1;
-  curl = fork_curl ("http://127.0.0.1:11080/");
-  sleep (1);
+  if (0 == port)
+    {
+      const union MHD_DaemonInfo *dinfo;
+      dinfo = MHD_get_daemon_info (d, MHD_DAEMON_INFO_BIND_PORT);
+      if (NULL == dinfo || 0 == dinfo->port)
+        { MHD_stop_daemon (d); return 32; }
+      port = (int)dinfo->port;
+    }
+  snprintf (url,
+            sizeof (url),
+            "http://127.0.0.1:%d/",
+            port);
+  curl = fork_curl (url);
+  (void)sleep (1);
   kill_curl (curl);
-  sleep (1);
-  // fprintf (stderr, "Stopping daemon!\n");
+  (void)sleep (1);
+  /* fprintf (stderr, "Stopping daemon!\n"); */
   MHD_stop_daemon (d);
   if (ok != 0)
     return 2;
@@ -176,21 +203,44 @@ testMultithreadedGet ()
 {
   struct MHD_Daemon *d;
   pid_t curl;
+  int port;
+  char url[127];
+
+  if (MHD_NO != MHD_is_feature_supported (MHD_FEATURE_AUTODETECT_BIND_PORT))
+    port = 0;
+  else
+    {
+      port = 1181;
+      if (oneone)
+        port += 10;
+    }
 
   ok = 1;
   d = MHD_start_daemon (MHD_USE_THREAD_PER_CONNECTION | MHD_USE_INTERNAL_POLLING_THREAD | MHD_USE_ERROR_LOG,
-                        1081, NULL, NULL, &ahc_echo, "GET",
+                        port, NULL, NULL, &ahc_echo, "GET",
 			MHD_OPTION_CONNECTION_TIMEOUT, (unsigned int) 2,
 			MHD_OPTION_END);
   if (d == NULL)
     return 16;
+  if (0 == port)
+    {
+      const union MHD_DaemonInfo *dinfo;
+      dinfo = MHD_get_daemon_info (d, MHD_DAEMON_INFO_BIND_PORT);
+      if (NULL == dinfo || 0 == dinfo->port)
+        { MHD_stop_daemon (d); return 32; }
+      port = (int)dinfo->port;
+    }
+  snprintf (url,
+            sizeof (url),
+            "http://127.0.0.1:%d/",
+            port);
   //fprintf (stderr, "Forking cURL!\n");
-  curl = fork_curl ("http://127.0.0.1:1081/");
-  sleep (1);
+  curl = fork_curl (url);
+  (void)sleep (1);
   kill_curl (curl);
-  sleep (1);
-  curl = fork_curl ("http://127.0.0.1:1081/");
-  sleep (1);
+  (void)sleep (1);
+  curl = fork_curl (url);
+  (void)sleep (1);
   if (ok != 0)
     {
       kill_curl (curl);
@@ -198,7 +248,7 @@ testMultithreadedGet ()
       return 64;
     }
   kill_curl (curl);
-  sleep (1);
+  (void)sleep (1);
   //fprintf (stderr, "Stopping daemon!\n");
   MHD_stop_daemon (d);
   if (ok != 0)
@@ -213,17 +263,40 @@ testMultithreadedPoolGet ()
 {
   struct MHD_Daemon *d;
   pid_t curl;
+  int port;
+  char url[127];
+
+  if (MHD_NO != MHD_is_feature_supported (MHD_FEATURE_AUTODETECT_BIND_PORT))
+    port = 0;
+  else
+    {
+      port = 1182;
+      if (oneone)
+        port += 10;
+    }
 
   ok = 1;
   d = MHD_start_daemon (MHD_USE_INTERNAL_POLLING_THREAD | MHD_USE_ERROR_LOG,
-                        1081, NULL, NULL, &ahc_echo, "GET",
+                        port, NULL, NULL, &ahc_echo, "GET",
                         MHD_OPTION_THREAD_POOL_SIZE, CPU_COUNT, MHD_OPTION_END);
   if (d == NULL)
     return 64;
-  curl = fork_curl ("http://127.0.0.1:1081/");
-  sleep (1);
+  if (0 == port)
+    {
+      const union MHD_DaemonInfo *dinfo;
+      dinfo = MHD_get_daemon_info (d, MHD_DAEMON_INFO_BIND_PORT);
+      if (NULL == dinfo || 0 == dinfo->port)
+        { MHD_stop_daemon (d); return 32; }
+      port = (int)dinfo->port;
+    }
+  snprintf (url,
+            sizeof (url),
+            "http://127.0.0.1:%d/",
+            port);
+  curl = fork_curl (url);
+  (void)sleep (1);
   kill_curl (curl);
-  sleep (1);
+  (void)sleep (1);
   //fprintf (stderr, "Stopping daemon!\n");
   MHD_stop_daemon (d);
   if (ok != 0)
@@ -243,13 +316,36 @@ testExternalGet ()
   time_t start;
   struct timeval tv;
   pid_t curl;
+  int port;
+  char url[127];
+
+  if (MHD_NO != MHD_is_feature_supported (MHD_FEATURE_AUTODETECT_BIND_PORT))
+    port = 0;
+  else
+    {
+      port = 1183;
+      if (oneone)
+        port += 10;
+    }
 
   ok = 1;
   d = MHD_start_daemon (MHD_USE_ERROR_LOG,
-                        1082, NULL, NULL, &ahc_echo, "GET", MHD_OPTION_END);
+                        port, NULL, NULL, &ahc_echo, "GET", MHD_OPTION_END);
   if (d == NULL)
     return 256;
-  curl = fork_curl ("http://127.0.0.1:1082/");
+  if (0 == port)
+    {
+      const union MHD_DaemonInfo *dinfo;
+      dinfo = MHD_get_daemon_info (d, MHD_DAEMON_INFO_BIND_PORT);
+      if (NULL == dinfo || 0 == dinfo->port)
+        { MHD_stop_daemon (d); return 32; }
+      port = (int)dinfo->port;
+    }
+  snprintf (url,
+            sizeof (url),
+            "http://127.0.0.1:%d/",
+            port);
+  curl = fork_curl (url);
 
   start = time (NULL);
   while ((time (NULL) - start < 2))
@@ -294,7 +390,7 @@ testExternalGet ()
         }
       MHD_run (d);
     }
-  // fprintf (stderr, "Stopping daemon!\n");
+  /* fprintf (stderr, "Stopping daemon!\n"); */
   MHD_stop_daemon (d);
   if (ok != 0)
     return 1024;
@@ -306,13 +402,18 @@ int
 main (int argc, char *const *argv)
 {
   unsigned int errorCount = 0;
-#ifdef __sun
-  struct sigaction act;
+  (void)argc;   /* Unused. Silent compiler warning. */
 
+#ifndef _WIN32
   /* Solaris has no way to disable SIGPIPE on socket disconnect. */
-  act.sa_handler = SIG_IGN;
-  sigaction(SIGPIPE, &act, NULL);
-#endif /* __sun */
+  if (MHD_NO == MHD_is_feature_supported (MHD_FEATURE_AUTOSUPPRESS_SIGPIPE))
+    {
+      struct sigaction act;
+
+      act.sa_handler = SIG_IGN;
+      sigaction(SIGPIPE, &act, NULL);
+    }
+#endif /* _WIN32 */
 
   oneone = (NULL != strrchr (argv[0], (int) '/')) ?
     (NULL != strstr (strrchr (argv[0], (int) '/'), "11")) : 0;
